Translate some german code comments to english!

This is contributed under the terms of the MPL 1.1 / GPLv3+ / LGPLv3+ triple
license.
---
 sw/source/ui/inc/colmgr.hxx         |    5 +--
 sw/source/ui/inc/column.hxx         |    2 +-
 sw/source/ui/inc/conarc.hxx         |    4 +-
 sw/source/ui/inc/concustomshape.hxx |    4 +-
 sw/source/ui/inc/conform.hxx        |    2 +-
 sw/source/ui/inc/conpoly.hxx        |    4 +-
 sw/source/ui/inc/conrect.hxx        |    4 +-
 sw/source/ui/inc/content.hxx        |   33 +++++++++---------
 sw/source/ui/inc/conttree.hxx       |   12 +++---
 sw/source/ui/inc/cption.hxx         |    4 +-
 sw/source/ui/inc/dbinsdlg.hxx       |    2 +-
 sw/source/ui/inc/docstdlg.hxx       |    2 +-
 sw/source/ui/inc/drawbase.hxx       |   12 +++---
 sw/source/ui/inc/dselect.hxx        |    6 ++--
 sw/source/ui/inc/edtwin.hxx         |   64 +++++++++++++++++-----------------
 sw/source/ui/inc/envimg.hxx         |   26 +++++++-------
 sw/source/ui/inc/fldmgr.hxx         |   42 +++++++++++-----------
 17 files changed, 113 insertions(+), 115 deletions(-)

diff --git a/sw/source/ui/inc/colmgr.hxx b/sw/source/ui/inc/colmgr.hxx
index 3712aa1..7ded3b5 100644
--- a/sw/source/ui/inc/colmgr.hxx
+++ b/sw/source/ui/inc/colmgr.hxx
@@ -36,8 +36,7 @@ SW_DLLPUBLIC void FitToActualSize(SwFmtCol& rCol, sal_uInt16 
nWidth);
 class SW_DLLPUBLIC SwColMgr
 {
 public:
-        // lActWidth wird aus den Edits des Seitendialogs
-        // direkt uebergeben
+        // lActWidth is passed directly from the page dialogs edits
     SwColMgr(const SfxItemSet &rSet, sal_uInt16 nActWidth = USHRT_MAX);
     ~SwColMgr();
 
@@ -82,7 +81,7 @@ private:
     sal_uInt16                                 nWidth;
 };
 
-// INLINE METHODE --------------------------------------------------------
+// INLINE METHOD --------------------------------------------------------
 inline         sal_uInt16 SwColMgr::GetCount() const
 {
     return aFmtCol.GetNumCols();
diff --git a/sw/source/ui/inc/column.hxx b/sw/source/ui/inc/column.hxx
index 865e55c..d992060 100644
--- a/sw/source/ui/inc/column.hxx
+++ b/sw/source/ui/inc/column.hxx
@@ -99,7 +99,7 @@ class ColumnValueSet : public ValueSet
 };
 
 /*--------------------------------------------------------------------
-    Beschreibung:      Spaltendialog jetzt als TabPage
+    Description:       column dialog now as TabPage
  --------------------------------------------------------------------*/
 class SwColumnPage : public SfxTabPage
 {
diff --git a/sw/source/ui/inc/conarc.hxx b/sw/source/ui/inc/conarc.hxx
index 56204a2..3e2779e 100644
--- a/sw/source/ui/inc/conarc.hxx
+++ b/sw/source/ui/inc/conarc.hxx
@@ -32,7 +32,7 @@
 
 /*************************************************************************
 |*
-|* Rechteck zeichnen
+|* draw rectangle
 |*
 \************************************************************************/
 
@@ -48,7 +48,7 @@ public:
     virtual sal_Bool   MouseButtonUp(const MouseEvent& rMEvt);
     virtual sal_Bool   MouseButtonDown(const MouseEvent& rMEvt);
 
-    virtual void       Activate(const sal_uInt16 nSlotId);     // Funktion 
aktivieren
+    virtual void       Activate(const sal_uInt16 nSlotId);     // activate 
function
     virtual void       Deactivate();
 };
 
diff --git a/sw/source/ui/inc/concustomshape.hxx 
b/sw/source/ui/inc/concustomshape.hxx
index e2dd43b..254f670 100644
--- a/sw/source/ui/inc/concustomshape.hxx
+++ b/sw/source/ui/inc/concustomshape.hxx
@@ -37,7 +37,7 @@ class SfxRequest;
 
 /*************************************************************************
 |*
-|* Rechteck zeichnen
+|* draw rectangle
 |*
 \************************************************************************/
 
@@ -56,7 +56,7 @@ class ConstCustomShape : public SwDrawBase
     virtual sal_Bool MouseButtonUp(const MouseEvent& rMEvt);
     virtual sal_Bool MouseButtonDown(const MouseEvent& rMEvt);
 
-    virtual void Activate(const sal_uInt16 nSlotId);   // Function aktivieren
+    virtual void Activate(const sal_uInt16 nSlotId);   // activate function
 
     rtl::OUString GetShapeType() const;
     static rtl::OUString GetShapeTypeFromRequest( SfxRequest& rReq );
diff --git a/sw/source/ui/inc/conform.hxx b/sw/source/ui/inc/conform.hxx
index 28914d6..e7750d8 100644
--- a/sw/source/ui/inc/conform.hxx
+++ b/sw/source/ui/inc/conform.hxx
@@ -38,7 +38,7 @@ public:
                                        // Mouse- & Key-Events
     virtual sal_Bool MouseButtonDown(const MouseEvent& rMEvt);
 
-    virtual void Activate(const sal_uInt16 nSlotId);   // Function aktivieren
+    virtual void Activate(const sal_uInt16 nSlotId);   // activate function
     virtual void CreateDefaultObject();
 };
 
diff --git a/sw/source/ui/inc/conpoly.hxx b/sw/source/ui/inc/conpoly.hxx
index bcfb77e..a765d4f 100644
--- a/sw/source/ui/inc/conpoly.hxx
+++ b/sw/source/ui/inc/conpoly.hxx
@@ -32,7 +32,7 @@
 
 /*************************************************************************
 |*
-|* Basisklasse fuer alle Funktionen
+|* base class for all functions
 |*
 \************************************************************************/
 
@@ -48,7 +48,7 @@ public:
     virtual sal_Bool MouseButtonUp(const MouseEvent& rMEvt);
     virtual sal_Bool MouseButtonDown(const MouseEvent& rMEvt);
 
-    virtual void Activate(const sal_uInt16 nSlotId);   // Function aktivieren
+    virtual void Activate(const sal_uInt16 nSlotId);   // activate function
 };
 
 
diff --git a/sw/source/ui/inc/conrect.hxx b/sw/source/ui/inc/conrect.hxx
index a5ef397..5152bd2 100644
--- a/sw/source/ui/inc/conrect.hxx
+++ b/sw/source/ui/inc/conrect.hxx
@@ -33,7 +33,7 @@
 
 /*************************************************************************
 |*
-|* Rechteck zeichnen
+|* draw rectangle
 |*
 \************************************************************************/
 
@@ -52,7 +52,7 @@ class ConstRectangle : public SwDrawBase
     virtual sal_Bool MouseButtonUp(const MouseEvent& rMEvt);
     virtual sal_Bool MouseButtonDown(const MouseEvent& rMEvt);
 
-    virtual void Activate(const sal_uInt16 nSlotId);   // Function aktivieren
+    virtual void Activate(const sal_uInt16 nSlotId);   // activate function
 };
 
 
diff --git a/sw/source/ui/inc/content.hxx b/sw/source/ui/inc/content.hxx
index 5c75666..60f9150 100644
--- a/sw/source/ui/inc/content.hxx
+++ b/sw/source/ui/inc/content.hxx
@@ -41,7 +41,7 @@ class SwTOXBase;
 class SwRedline;
 
 //----------------------------------------------------------------------------
-//     Hilfsklassen
+//     helper classes
 //----------------------------------------------------------------------------
 
 class SwPopup : public PopupMenu
@@ -169,29 +169,28 @@ public:
     const SwTOXBase* GetTOXBase() const {return pBase;}
 };
 /*
-    class ContentType enthaelt Informationen zu einer Inhaltsform
-    Das MemberArray wird nur gefuellt, wenn der Inhalt mit GetMember
-    angefordert wird. Es wird nach Invalidate() nur dann neu geladen,
-    wenn der Inhalt erneut ausgelesen werden soll.
+    class ContentType contains information to one type of content.
+    MemberArray is only populated if the content is requested by
+    GetMember. It is reloaded after Invalidate() only if the content
+    should be read again.
 */
 //----------------------------------------------------------------------------
-//----------------------------------------------------------------------------
 
 class SwContentType : public SwTypeNumber
 {
     SwWrtShell*                pWrtShell;
-    SwContentArr*              pMember;                        // Array fuer 
Inhalte
-    String                             sContentTypeName;       // Name der 
Inhaltsform
-    String                             sSingleContentTypeName; // Name der 
Inhaltsform, Singular
-    String                             sTypeToken;                     // 
Anhaengsel fuer URL
-    sal_uInt16                         nMemberCount;           // Inhaltsanzahl
-    sal_uInt16                         nContentType;           // Id der 
Inhaltsform
+    SwContentArr*              pMember;                        // array for 
content
+    String                             sContentTypeName;       // name of 
content type
+    String                             sSingleContentTypeName; // name of 
content type, singular
+    String                             sTypeToken;                     // 
attachment for URL
+    sal_uInt16                         nMemberCount;           // content count
+    sal_uInt16                         nContentType;           // content 
type's Id
     sal_uInt8                          nOutlineLevel;
-    sal_Bool                           bMemberFilled : 1;      // wurden die 
Inhalte bereits eingefuegt?
-    sal_Bool                           bIsInternalDrag:1;      // koennen die 
Inhalte verschoben werden?
+    sal_Bool                           bMemberFilled : 1;      // has content 
already been inserted?
+    sal_Bool                           bIsInternalDrag:1;      // can content 
be relocated?
     sal_Bool                           bDataValid :    1;  //
-    sal_Bool                           bEdit:                  1;      // kann 
diese Type bearbeitet werden ?
-    sal_Bool                           bDelete:                1;      // kann 
diese Type geloescht werden ?
+    sal_Bool                           bEdit:                  1;      // can 
this type be edited?
+    sal_Bool                           bDelete:                1;      // can 
this type be deleted?
 protected:
         void                   RemoveNewline(String&);
 public:
@@ -214,7 +213,7 @@ public:
                                 Invalidate();
                             }
 
-        void                           Invalidate(); // nur nMemberCount wird 
neu gelesen
+        void                           Invalidate(); // only nMemberCount is 
read again
 
         sal_Bool                               IsEditable() const {return 
bEdit;}
         sal_Bool                               IsDeletable() const {return 
bDelete;}
diff --git a/sw/source/ui/inc/conttree.hxx b/sw/source/ui/inc/conttree.hxx
index f6e8468..899f7d6 100644
--- a/sw/source/ui/inc/conttree.hxx
+++ b/sw/source/ui/inc/conttree.hxx
@@ -73,8 +73,8 @@ class SwContentTree : public SvTreeListBox
     String                             sPostItHide;
     String                             sPostItDelete;
 
-    SwWrtShell*                pHiddenShell;   // gedropptes Doc
-    SwWrtShell*                pActiveShell;   // die aktive oder eine konst. 
offene View
+    SwWrtShell*                pHiddenShell;   // dropped Doc
+    SwWrtShell*                pActiveShell;   // the active or a const. open 
view
     SwNavigationConfig*        pConfig;
 
     std::map< void*, sal_Bool > mOutLineNodeMap;
@@ -207,7 +207,7 @@ public:
 
 
 //----------------------------------------------------------------------------
-// TreeListBox fuer Globaldokumente
+// TreeListBox for global documents
 //----------------------------------------------------------------------------
 
 class SwLBoxString : public SvLBoxString
@@ -235,9 +235,9 @@ private:
     ImageList                  aEntryImages;
 
     SwWrtShell*             pActiveShell;   //
-    SvLBoxEntry*            pEmphasisEntry; // Drag'n Drop-Emphasis
-    SvLBoxEntry*            pDDSource;      // Quelle beim DnD
-    SwGlblDocContents*      pSwGlblDocContents; // Array mit sortierten 
Inhalten
+    SvLBoxEntry*            pEmphasisEntry; // Drag'n Drop emphasis
+    SvLBoxEntry*            pDDSource;      // source for Drag'n Drop
+    SwGlblDocContents*      pSwGlblDocContents; // array with sorted content
 
     Window*                 pDefParentWin;
     SwGlblDocContent*       pDocContent;
diff --git a/sw/source/ui/inc/cption.hxx b/sw/source/ui/inc/cption.hxx
index b6fe3e7..f23f4be 100644
--- a/sw/source/ui/inc/cption.hxx
+++ b/sw/source/ui/inc/cption.hxx
@@ -95,8 +95,8 @@ class SwCaptionDialog : public SvxStandardDialog
 
     SwCaptionPreview    aPrevWin;
 
-    SwView       &rView; //Suchen per aktive ::com::sun::star::sdbcx::View 
vermeiden.
-    SwFldMgr     *pMgr;      //Ptr um das include zu sparen
+    SwView       &rView; // search per active, avoid 
::com::sun::star::sdbcx::View
+    SwFldMgr     *pMgr;      // pointer to save the include
     SelectionType eType;
 
     String       sCharacterStyle;
diff --git a/sw/source/ui/inc/dbinsdlg.hxx b/sw/source/ui/inc/dbinsdlg.hxx
index e299bff..89a5948 100644
--- a/sw/source/ui/inc/dbinsdlg.hxx
+++ b/sw/source/ui/inc/dbinsdlg.hxx
@@ -160,7 +160,7 @@ class SwInsertDBColAutoPilot : public SfxModalDialog, 
public utl::ConfigItem
     virtual void                       Commit();
     void                                       Load();
 
-    // setze die Tabellen - Eigenschaften
+    // set the tables - properties
     void SetTabSet();
 
 public:
diff --git a/sw/source/ui/inc/docstdlg.hxx b/sw/source/ui/inc/docstdlg.hxx
index ee4fc41..233f7d2 100644
--- a/sw/source/ui/inc/docstdlg.hxx
+++ b/sw/source/ui/inc/docstdlg.hxx
@@ -36,7 +36,7 @@
 #include "docstat.hxx"
 
 /*--------------------------------------------------------------------
-    Beschreibung:   DocInfo jetzt als Page
+    Description:   DocInfo now as page
  --------------------------------------------------------------------*/
 class SwDocStatPage: public SfxTabPage
 {
diff --git a/sw/source/ui/inc/drawbase.hxx b/sw/source/ui/inc/drawbase.hxx
index 47f7a2d..24430ca 100644
--- a/sw/source/ui/inc/drawbase.hxx
+++ b/sw/source/ui/inc/drawbase.hxx
@@ -40,7 +40,7 @@ class MouseEvent;
 
 /*************************************************************************
 |*
-|* Basisklasse fuer alle Funktionen
+|* base class for all functions
 |*
 \************************************************************************/
 
@@ -50,8 +50,8 @@ protected:
     SwView*         m_pView;
     SwWrtShell*     m_pSh;
     SwEditWin*      m_pWin;
-    Point           m_aStartPos;                 // Position von BeginCreate
-    Point           m_aMDPos;                // Position von MouseButtonDown
+    Point           m_aStartPos;                 // position of BeginCreate
+    Point           m_aMDPos;                // position of MouseButtonDown
     sal_uInt16          m_nSlotId;
     sal_Bool            m_bCreateObj  :1;
     sal_Bool            m_bInsForm   :1;
@@ -66,7 +66,7 @@ public:
     inline sal_Bool  IsInsertForm() const { return m_bInsForm; }
     inline sal_Bool  IsCreateObj() const { return m_bCreateObj; }
 
-    // Mouse- & Key-Events; Returnwert=sal_True: Event wurde bearbeitet
+    // mouse- & key events; return value=sal_True: event was edited
     virtual sal_Bool KeyInput(const KeyEvent& rKEvt);
     virtual sal_Bool MouseMove(const MouseEvent& rMEvt);
     virtual sal_Bool MouseButtonUp(const MouseEvent& rMEvt);
@@ -76,8 +76,8 @@ public:
     void         SetSlotId(sal_uInt16 nSlot) {m_nSlotId = nSlot;}
     sal_uInt16       GetSlotId() { return m_nSlotId;}
 
-    virtual void Activate(const sal_uInt16 nSlotId);   // Function aktivieren
-    virtual void Deactivate();                                         // 
Function deaktivieren
+    virtual void Activate(const sal_uInt16 nSlotId);   // activate fuction
+    virtual void Deactivate();                                         // 
deactivate function
 
     virtual void CreateDefaultObject();
 
diff --git a/sw/source/ui/inc/dselect.hxx b/sw/source/ui/inc/dselect.hxx
index 165ae46..fa6e036 100644
--- a/sw/source/ui/inc/dselect.hxx
+++ b/sw/source/ui/inc/dselect.hxx
@@ -32,7 +32,7 @@
 
 /*************************************************************************
 |*
-|* Rechteck zeichnen
+|* draw rectangle
 |*
 \************************************************************************/
 
@@ -41,10 +41,10 @@ class DrawSelection : public SwDrawBase
  public:
     DrawSelection(SwWrtShell* pSh, SwEditWin* pWin, SwView* pView);
 
-                                       // Mouse- & Key-Events
+                                       // mouse- & key events
     virtual sal_Bool KeyInput(const KeyEvent& rKEvt);
 
-    virtual void Activate(const sal_uInt16 nSlotId);   // Function aktivieren
+    virtual void Activate(const sal_uInt16 nSlotId);   // activate function
 };
 
 
diff --git a/sw/source/ui/inc/edtwin.hxx b/sw/source/ui/inc/edtwin.hxx
index 3db9f7c..3cb83fa 100644
--- a/sw/source/ui/inc/edtwin.hxx
+++ b/sw/source/ui/inc/edtwin.hxx
@@ -54,7 +54,7 @@ struct        QuickHelpData;
 class SdrDropMarkerOverlay;
 
 /*--------------------------------------------------------------------
-    Beschreibung:      Eingabe-Fenster
+    Description:       input window
  --------------------------------------------------------------------*/
 
 class SwEditWin: public Window,
@@ -76,18 +76,18 @@ friend void         PageNumNotify(  ViewShell* pVwSh,
     static     sal_Bool        bReplaceQuote;
     static     long    nDDStartPosX, nDDStartPosY;
 
-    static     Color   aTextColor;     //Textfarbe, fuer die Giesskanne
-    static     sal_Bool        bTransparentBackColor; // Hintergrund 
transparent
-    static     Color   aTextBackColor; //Texthintergrundfarbe, fuer die 
Giesskanne
+    static     Color   aTextColor;     // text color; for the watering can
+    static     sal_Bool        bTransparentBackColor; // transparent background
+    static     Color   aTextBackColor; // text background; for the watering can
 
     /*
-     * Timer und Handler fuer das Weiterscrollen, wenn der
-     * Mauspointer innerhalb eines Drag-Vorgangs ausserhalb des
-     * EditWin stehen bleibt.  In regelmaessigen Intervallen wird
-     * die Selektion in Richtung der Mausposition vergroessert.
+     * timer and handler for scrolling on when the mousepointer
+     * stopps outside of EditWin during a drag-operation.
+     * The selection is increased towards the mouse position
+     * regularly.
      */
     AutoTimer          aTimer;
-    // Timer fuer verschachtelte KeyInputs (z.B. fuer Tabellen)
+    // timer for overlapping KeyInputs (e.g. for tables)
     Timer                      aKeyInputTimer;
     // timer for ANY-KeyInut question without a following KeyInputEvent
     Timer                      aKeyInputFlushTimer;
@@ -99,11 +99,11 @@ friend void         PageNumNotify(  ViewShell* pVwSh,
     Point                      aRszMvHdlPt;
     Timer                      aTemplateTimer;
 
-    // Type/Objecte ueber dem der MousePointer steht
+    // type/object where the mouse pointer is 
     SwCallMouseEvent aSaveCallEvent;
 
     SwApplyTemplate    *pApplyTempl;
-    SwAnchorMarker             *pAnchorMarker; // zum Verschieben eines Ankers
+    SwAnchorMarker             *pAnchorMarker; // for relocating the anchor
 
     SdrDropMarkerOverlay       *pUserMarker;
     SdrObject                          *pUserMarkerObj;
@@ -112,29 +112,29 @@ friend void       PageNumNotify(  ViewShell* pVwSh,
 
     SwView                &rView;
 
-    int                                aActHitType;    // aktueller Mauspointer
+    int                                aActHitType;    // current mouse pointer
 
-    sal_uLong           m_nDropFormat;   //Format aus dem letzten QueryDrop
-    sal_uInt16          m_nDropAction;   //Action aus dem letzten QueryDrop
-    sal_uInt16          m_nDropDestination;  //Ziel aus dem letzten QueryDrop
+    sal_uLong           m_nDropFormat;   // format from the last QueryDrop
+    sal_uInt16          m_nDropAction;   // action from the last QueryDrop
+    sal_uInt16          m_nDropDestination;  // destination from the last 
QueryDrop
 
     sal_uInt16                 eBezierMode;
-    sal_uInt16                 nInsFrmColCount; //Spaltenzahl fuer 
interaktiven Rahmen
+    sal_uInt16                 nInsFrmColCount; // column number for 
interactive frame
     SdrObjKind         eDrawMode;
     sal_Bool                   bLinkRemoved    : 1,
                     bMBPressed         : 1,
                     bInsDraw           : 1,
                     bInsFrm            : 1,
                     bIsInMove          : 1,
-                    bIsInDrag          : 1, //StartExecuteDrag nich doppelt 
ausfuehren
-                    bOldIdle           : 1, //Zum abschalten des Idle'ns
-                    bOldIdleSet                : 1, //waehrend QeueryDrop
+                    bIsInDrag          : 1, // don't execute StartExecuteDrag 
twice
+                    bOldIdle           : 1, // to stop to idle
+                    bOldIdleSet                : 1, // during QeueryDrop
                     bTblInsDelMode     : 1, //
                     bTblIsInsMode      : 1, //
                     bTblIsColMode      : 1, //
-                    bChainMode         : 1, //Rahmen verbinden
-                    bWasShdwCrsr       : 1, //ShadowCrsr war im 
MouseButtonDown an
-                    bLockInput      : 1, //Lock waehrend die Rechenleiste 
aktiv ist
+                    bChainMode         : 1, // connect frames
+                    bWasShdwCrsr       : 1, // ShadowCrsr was on in 
MouseButtonDown
+                    bLockInput      : 1, // lock while calc panel is active
                     bIsRowDrag      : 1, //selection of rows is used, in 
combination with pRowColumnSelectionStart
                     /** #i42732# display status of font size/name depending on 
either the input language or the
                         selection position depending on what has changed lately
@@ -158,7 +158,7 @@ friend void         PageNumNotify(  ViewShell* pVwSh,
     sal_Bool                   EnterDrawMode(const MouseEvent& rMEvt, const 
Point& aDocPos);
     sal_Bool            RulerColumnDrag( const MouseEvent& rMEvt, sal_Bool 
bVerticalMode);
 
-    //Hilfsfunktionen fuer D&D
+    // helper function for D&D
     void                       DropCleanup();
     void                       CleanupDropUserMarker();
     sal_uInt16                 GetDropDestination( const Point& rPixPnt,
@@ -167,10 +167,10 @@ friend void       PageNumNotify(  ViewShell* pVwSh,
     sal_Bool            SelectMenuPosition(SwWrtShell& rSh, const Point& 
rMousePos );
 
     /*
-     * Handler fuer das Weiterscrollen, wenn der Mauspointer innerhalb eines
-     * Drag-Vorgangs ausserhalb des EditWin stehen bleibt. In regelmaessigen
-     * Intervallen wird die Selektion in Richtung der Mausposition
-     * vergroessert.
+     * handler for scrolling on when the mousepointer
+     * stopps outside of EditWin during a drag-operation.
+     * The selection is regularly increased towards the mouse 
+     * position.
      */
     DECL_LINK( TimerHandler, Timer * );
     void                       StartDDTimer();
@@ -180,10 +180,10 @@ friend void       PageNumNotify(  ViewShell* pVwSh,
     // timer for ANY-KeyInut question without a following KeyInputEvent
     DECL_LINK( KeyInputFlushHandler, Timer * );
 
-    // Timer fuer verschachtelte KeyInputs (z.B. fuer Tabellen)
+    // timer for overlapping KeyInputs (e.g. for tables)
     DECL_LINK( KeyInputTimerHandler, Timer * );
 
-    // Timer fuer das ApplyTemplates per Maus (verkapptes Drag&Drop)
+    // timer for ApplyTemplates via mouse (in disguise Drag&Drop)
     DECL_LINK( TemplateTimerHdl, Timer* );
 
     using OutputDevice::GetTextColor;
@@ -234,10 +234,10 @@ public:
     sal_Bool                   IsFrmAction()                                   
{ return (bInsFrm); }
     inline sal_uInt16  GetBezierMode()                                 { 
return eBezierMode; }
     void                       SetBezierMode(sal_uInt16 eBezMode)      { 
eBezierMode = eBezMode; }
-    void                       EnterDrawTextMode(const Point& aDocPos); // 
DrawTextEditMode einschalten
+    void                       EnterDrawTextMode(const Point& aDocPos); // 
turn on DrawTextEditMode 
     void                       InsFrm(sal_uInt16 nCols);
     void                       StopInsFrm();
-    sal_uInt16                 GetFrmColCount() const {return 
nInsFrmColCount;} //Spaltenzahl fuer interaktiven Rahmen
+    sal_uInt16                 GetFrmColCount() const {return 
nInsFrmColCount;} // column number for interactive frame
 
 
     void                       SetChainMode( sal_Bool bOn );
@@ -277,7 +277,7 @@ public:
 
     virtual ::com::sun::star::uno::Reference< 
::com::sun::star::accessibility::XAccessible > CreateAccessible();
 
-    // Tipfenster loeschen
+    // delete tip window
     static void ClearTip();
 
     static inline long GetDDStartPosX() { return nDDStartPosX; }
diff --git a/sw/source/ui/inc/envimg.hxx b/sw/source/ui/inc/envimg.hxx
index 4b0ddc8..6eae7d9 100644
--- a/sw/source/ui/inc/envimg.hxx
+++ b/sw/source/ui/inc/envimg.hxx
@@ -51,19 +51,19 @@ class SW_DLLPUBLIC SwEnvItem : public SfxPoolItem
 {
 public:
 
-    rtl::OUString   aAddrText;       // Text fuer Empfaenger
-    sal_Bool           bSend;           // Absender?
-    rtl::OUString      aSendText;       // Text fuer Absender
-    sal_Int32       lAddrFromLeft;   // Linker Abstand fuer Empfaenger (twips)
-    sal_Int32       lAddrFromTop;    // Oberer Abstand fuer Empfaenger (twips)
-    sal_Int32       lSendFromLeft;   // Linker Abstand fuer Absender   (twips)
-    sal_Int32       lSendFromTop;    // Oberer Abstand fuer Absender   (twips)
-    sal_Int32       lWidth;          // Breite des Umschlags           (twips)
-    sal_Int32       lHeight;         // Hoehe  des Umschlags           (twips)
-    SwEnvAlign                 eAlign;          // Ausrichtung beim Einzug
-    sal_Bool           bPrintFromAbove; // Von oben drucken?
-    sal_Int32       lShiftRight;     // Verschiebung nach rechts       (twips)
-    sal_Int32       lShiftDown;      // Verschiebung nach unten        (twips)
+    rtl::OUString   aAddrText;       // text for reciever
+    sal_Bool           bSend;           // sender?
+    rtl::OUString      aSendText;       // text for sender
+    sal_Int32       lAddrFromLeft;   // left gap for reciever (twips)
+    sal_Int32       lAddrFromTop;    // upper gap for reciever (twips)
+    sal_Int32       lSendFromLeft;   // left gap for sender (twips)
+    sal_Int32       lSendFromTop;    // upper gap for sender (twips)
+    sal_Int32       lWidth;          // envelope's width (twips)
+    sal_Int32       lHeight;         // envelope's height (twips)
+    SwEnvAlign                 eAlign;          // alignment at indent
+    sal_Bool           bPrintFromAbove; // print from above?
+    sal_Int32       lShiftRight;     // shift to right (twips)
+    sal_Int32       lShiftDown;      // shift down (twips)
 
     SwEnvItem();
     SwEnvItem(const SwEnvItem& rItem);
diff --git a/sw/source/ui/inc/fldmgr.hxx b/sw/source/ui/inc/fldmgr.hxx
index 6689bfd..ca89df4 100644
--- a/sw/source/ui/inc/fldmgr.hxx
+++ b/sw/source/ui/inc/fldmgr.hxx
@@ -55,7 +55,7 @@ class SvNumberFormatter;
 class Window;
 
 /*--------------------------------------------------------------------
-    Beschreibung: Die Gruppen von Feldern
+    Description: the groups of fields
  --------------------------------------------------------------------*/
 enum SwFldGroups
 {
@@ -74,8 +74,8 @@ struct SwFldGroupRgn
 };
 
 /*--------------------------------------------------------------------
-    Beschreibung:  Der FeldManager handelt das Einfuegen von Felder
-                    ueber Command-Strings
+    Description:  the field manager handles the insertation of fields 
+                  with command strings
  --------------------------------------------------------------------*/
 struct SwInsertFld_Data
 {
@@ -117,7 +117,7 @@ private:
     SwField*                   pCurFld;
     SbModule*                  pModule;
     const SvxMacroItem*        pMacroItem;
-    SwWrtShell*                pWrtShell; // darf auch NULL sein!
+    SwWrtShell*                pWrtShell; // can be ZERO too!
     String                     aCurPar1;
     String                     aCurPar2;
     String                     sCurFrame;
@@ -141,10 +141,10 @@ public:
     void                SetWrtShell( SwWrtShell* pShell )
                         {   pWrtShell = pShell;     }                          
          
     
     // Feld einfuegen ueber TypeId (TYP_ ...)
     sal_Bool            InsertFld(  const SwInsertFld_Data& rData );
 
-    // Direkt das aktuelle Feld aendern
+    // change the current field directly
     void                       UpdateCurFld(sal_uLong nFormat,
                                  const String& rPar1,
                                  const String& rPar2,
@@ -154,7 +154,7 @@ public:
     inline const String& GetCurFldPar2() const;
     inline sal_uLong   GetCurFldFmt() const;
 
-    // Ein Feld ermitteln
+    // determine a field
     SwField*           GetCurFld();
 
     void                       InsertFldType(SwFieldType& rType);
@@ -165,54 +165,54 @@ public:
     inline const String& GetMacroName() const            { return 
(sMacroName); }
     inline void                SetMacroModule(SbModule* pMod)    { pModule = 
pMod; }
 
-    // Vorheriger Naechster gleichen Typ
+    // previous and next of the same type
     sal_Bool GoNextPrev( sal_Bool bNext = sal_True, SwFieldType* pTyp = 0 );
     sal_Bool GoNext( SwFieldType* pTyp = 0 )   { return GoNextPrev( sal_True, 
pTyp ); }
     sal_Bool GoPrev( SwFieldType* pTyp = 0 )   { return GoNextPrev( sal_False, 
pTyp ); }
 
-    // Erfragen von Werten aus Datenbankfeldern (BASIC )
+    // query values from database fields (BASIC )
 //     String                  GetDataBaseFieldValue(const String &rDBName, 
const String &rFieldName, SwWrtShell* pSh);
     sal_Bool                   IsDBNumeric(const String& rDBName, const 
String& rTblQryName,
                                         sal_Bool bIsTable, const String& 
rFldName);
 
-    // RefMark mit Namen organisieren
+    // organise RefMark with names 
     sal_Bool                   CanInsertRefMark( const String& rStr );
 
 
-    // Zugriff ueber ResId auf Feldtypen
+    // access to field types via ResId
     sal_uInt16                         GetFldTypeCount(sal_uInt16 nResId = 
USHRT_MAX) const;
     SwFieldType*       GetFldType(sal_uInt16 nResId, sal_uInt16 nId = 0) const;
     SwFieldType*       GetFldType(sal_uInt16 nResId, const String& rName) 
const;
 
     void                       RemoveFldType(sal_uInt16 nResId, const String& 
rName);
 
-    // Zugriff ueber TypeId aus dem Dialog
-    // Ids fuer einen Bereich von Feldern
+    // access via TypeId from the dialog
+    // Ids for a range of fields
     const SwFldGroupRgn& GetGroupRange(sal_Bool bHtmlMode, sal_uInt16 nGrpId) 
const;
     sal_uInt16                 GetGroup(sal_Bool bHtmlMode, sal_uInt16 
nTypeId, sal_uInt16 nSubType = 0) const;
 
-    // TypeId des aktuellen Feldes
+    // the current field's TypeId
     sal_uInt16                 GetCurTypeId() const;
 
-    // TypeId fuer einen konkrete Pos in der Liste
+    // TypeId for a concrete position in the list
     static sal_uInt16   GetTypeId(sal_uInt16 nPos);
-    // Name des Typen in der Liste der Felder
+    // name of the type in the list of fields
     static const String&  GetTypeStr(sal_uInt16 nPos);
 
-    // Pos in der Liste der Felder
+    // Pos in the list of fields
     static sal_uInt16   GetPos(sal_uInt16 nTypeId);
 
-    // Untertypen zu einem Typ
+    // subtypes to a type
     sal_Bool            GetSubTypes(sal_uInt16 nId, SvStringsDtor& rToFill);
 
-    // Formate zu einem Typ
+    // format to a type
     sal_uInt16                         GetFormatCount(sal_uInt16 nTypeId, 
sal_Bool bIsText, sal_Bool bHtmlMode = sal_False) const;
     String                     GetFormatStr(sal_uInt16 nTypeId, sal_uLong 
nFormatId) const;
     sal_uInt16                 GetFormatId(sal_uInt16 nTypeId, sal_uLong 
nFormatId) const;
     sal_uLong                  GetDefaultFormat(sal_uInt16 nTypeId, sal_Bool 
bIsText, SvNumberFormatter* pFormatter, double* pVal = 0L);
 
-    // Evaluierung der ExpressionFelder ausschalten fuer das Einfuegen
-    // vieler Expressionfelder (siehe Etiketten)
+    // turn off evaluation of expression fields for insertation
+    // of many expressino fields (see labels)
     //
     inline void                SetEvalExpFlds(sal_Bool bEval);
     void                       EvalExpFlds(SwWrtShell* pSh = NULL);
@@ -141,10 +141,10 @@ public:
          
     
-    // Feld einfuegen ueber TypeId (TYP_ ...)
+    // insert field using TypeID (TYP_ ...)
     sal_Bool            InsertFld(  const SwInsertFld_Data& rData );
 
-- 
1.7.1

_______________________________________________
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice

Reply via email to